aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorCôme Chilliet <91878298+come-nc@users.noreply.github.com>2023-09-26 09:39:10 +0200
committerGitHub <noreply@github.com>2023-09-26 09:39:10 +0200
commit2ebd5bb939a2e57b569bc6713290af67a3d91689 (patch)
tree875063ab9a0da9d9520e564489082cbc57f08bbd
parent9d0db222cf718621556017e7ec7eac171c3547a0 (diff)
parente0eb9a8ce9d4a532737a02c28bca573066f711bb (diff)
downloadnextcloud-server-2ebd5bb939a2e57b569bc6713290af67a3d91689.tar.gz
nextcloud-server-2ebd5bb939a2e57b569bc6713290af67a3d91689.zip
Merge pull request #40623 from nextcloud/backport/40501/stable27
[stable27] Store size in int|float for 32bit support
-rw-r--r--lib/private/Files/Cache/Scanner.php9
-rw-r--r--lib/private/Files/ObjectStore/ObjectStoreScanner.php2
2 files changed, 7 insertions, 4 deletions
diff --git a/lib/private/Files/ObjectStore/ObjectStoreScanner.php b/lib/private/Files/ObjectStore/ObjectStoreScanner.php
index f001f90fdaa..d827662ae0b 100644
--- a/lib/private/Files/ObjectStore/ObjectStoreScanner.php
+++ b/lib/private/Files/ObjectStore/ObjectStoreScanner.php
@@ -39,7 +39,7 @@ class ObjectStoreScanner extends Scanner {
return [];
}
- protected function scanChildren(string $path, $recursive, int $reuse, int $folderId, bool $lock, int $oldSize) {
+ protected function scanChildren(string $path, $recursive, int $reuse, int $folderId, bool $lock, int|float $oldSize) {
return 0;
}
diff --git a/lib/private/Files/Cache/Scanner.php b/lib/private/Files/Cache/Scanner.php
index 9bd94edf5bc..9f99bbaab2b 100644
--- a/lib/private/Files/Cache/Scanner.php
+++ b/lib/private/Files/Cache/Scanner.php
@@ -385,10 +385,10 @@ class Scanner extends BasicEmitter implements IScanner {
* @param int $reuse a combination of self::REUSE_*
* @param int $folderId id for the folder to be scanned
* @param bool $lock set to false to disable getting an additional read lock during scanning
* @param int $oldSize the size of the folder before (re)scanning the children
* @return int|float the size of the scanned folder or -1 if the size is unknown at this stage
*/
- protected function scanChildren(string $path, $recursive, int $reuse, int $folderId, bool $lock, int $oldSize) {
+ protected function scanChildren(string $path, $recursive, int $reuse, int $folderId, bool $lock, int|float $oldSize) {
if ($reuse === -1) {
$reuse = ($recursive === self::SCAN_SHALLOW) ? self::REUSE_ETAG | self::REUSE_SIZE : self::REUSE_ETAG;
}
@@ -418,7 +418,10 @@ class Scanner extends BasicEmitter implements IScanner {
return $size;
}
- private function handleChildren($path, $recursive, $reuse, $folderId, $lock, &$size) {
+ /**
+ * @param bool|IScanner::SCAN_RECURSIVE_INCOMPLETE $recursive
+ */
+ private function handleChildren(string $path, $recursive, int $reuse, int $folderId, bool $lock, int|float &$size): array {
// we put this in it's own function so it cleans up the memory before we start recursing
$existingChildren = $this->getExistingChildren($folderId);
$newChildren = iterator_to_array($this->storage->getDirectoryContent($path));
@@ -385,10 +385,10 @@ class Scanner extends BasicEmitter implements IScanner {
* @param int $folderId id for the folder to be scanned
* @param bool $lock set to false to disable getting an additional read lock during scanning
- * @param int $oldSize the size of the folder before (re)scanning the children
+ * @param int|float $oldSize the size of the folder before (re)scanning the children
* @return int|float the size of the scanned folder or -1 if the size is unknown at this stage
*/